@@ -61,20 +61,7 @@ void initResourcePath(GladeSearchpath* gladePath, const gchar* relativePathAndFi
 
 void initLocalisation() {
 #ifdef ENABLE_NLS
-
-#ifdef _WIN32
-#undef PACKAGE_LOCALE_DIR
-#define PACKAGE_LOCALE_DIR "../share/locale/"
-#endif
-
-#ifdef __APPLE__
-#undef PACKAGE_LOCALE_DIR
-    fs::path p = Stacktrace::getExePath();
-    p /= "../Resources/share/locale/";
-    const char* PACKAGE_LOCALE_DIR = p.c_str();
-#endif
-
-    fs::path localeDir = Util::getGettextFilepath(PACKAGE_LOCALE_DIR);
+    fs::path localeDir = Util::getGettextFilepath(Util::getLocalePath().u8string().c_str());
     bindtextdomain(GETTEXT_PACKAGE, localeDir.u8string().c_str());
     textdomain(GETTEXT_PACKAGE);
 
@@ -93,6 +80,12 @@ void initLocalisation() {
                   "xournalpp with msvc",
                   e.what());
     }
+    /**
+     * Force numbers to be printed out and parsed by C libraries (cairo) in the "classic" locale.
+     * This avoids issue with tags when exporting to PDF, see #3551
+     */
+    setlocale(LC_NUMERIC, "C");
+
     std::cout.imbue(std::locale());
 }
 
@@ -114,12 +107,12 @@ auto migrateSettings() -> MigrateResult {
             Util::ensureFolderExists(newConfigPath.parent_path());
             try {
                 fs::copy(oldPath, newConfigPath, fs::copy_options::recursive);
-                constexpr auto msg = "Due to a recent update, Xournal++ has changed where it's configuration files are "
+                constexpr auto msg = "Due to a recent update, Xournal++ has changed where its configuration files are "
                                      "stored.\nThey have been automatically copied from\n\t{1}\nto\n\t{2}";
                 return {MigrateStatus::Success, FS(_F(msg) % oldPath.u8string() % newConfigPath.u8string())};
             } catch (fs::filesystem_error const& except) {
                 constexpr auto msg =
-                        "Due to a recent update, Xournal++ has changed where it's configuration files are "
+                        "Due to a recent update, Xournal++ has changed where its configuration files are "
                         "stored.\nHowever, when attempting to copy\n\t{1}\nto\n\t{2}\nmigration failed:\n{3}";
                 g_message("Migration failed: %s", except.what());
                 return {MigrateStatus::Failure,
@@ -148,7 +141,7 @@ void checkForErrorlog() {
     }
 
     std::sort(errorList.begin(), errorList.end());
-    string msg =
+    std::string msg =
             errorList.size() == 1 ?
                     _("There is an errorlogfile from Xournal++. Please send a Bugreport, so the bug may be fixed.") :
                     _("There are errorlogfiles from Xournal++. Please send a Bugreport, so the bug may be fixed.");
@@ -201,7 +194,7 @@ void checkForEmergencySave(Control* control) {
         return;
     }
 
-    string msg = _("Xournal++ crashed last time. Would you like to restore the last edited file?");
+    std::string msg = _("Xournal++ crashed last time. Would you like to restore the last edited file?");
 
     GtkWidget* dialog = gtk_message_dialog_new(nullptr, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s",
                                                msg.c_str());
@@ -286,7 +279,7 @@ auto exportImg(const char* input, const char* output, const char* range, int png
     for (PageRangeEntry* e: exportRange) { delete e; }
     exportRange.clear();
 
-    string errorMsg = imgExport.getLastErrorMsg();
+    std::string errorMsg = imgExport.getLastErrorMsg();
     if (!errorMsg.empty()) {
         g_message("Error exporting image: %s\n", errorMsg.c_str());
     }
@@ -321,7 +314,7 @@ auto exportPdf(const char* input, const char* output, const char* range, ExportB
     XojPdfExport* pdfe = XojPdfExportFactory::createExport(doc, nullptr);
     pdfe->setExportBackground(exportBackground);
     char* cpath = g_file_get_path(file);
-    string path = cpath;
+    std::string path = cpath;
     g_free(cpath);
     g_object_unref(file);
 
@@ -384,9 +377,11 @@ using XMPtr = XournalMainPrivate*;
 /// Checks for input method compatibility and ensures it
 void ensure_input_model_compatibility() {
     const char* imModule = g_getenv("GTK_IM_MODULE");
-    if (imModule != nullptr && strcmp(imModule, "xim") == 0) {
-        g_setenv("GTK_IM_MODULE", "ibus", true);
-        g_warning("Unsupported input method: xim, changed to: ibus");
+    if (imModule != nullptr) {
+        std::string imModuleString{imModule};
+        if (imModuleString == "xim" || imModuleString == "gcin") {
+            g_warning("Unsupported input method: %s", imModule);
+        }
     }
 }
 
@@ -433,9 +428,7 @@ void initResourcePath(GladeSearchpath* gladePath, const gchar* relativePathAndFi
 
     // -----------------------------------------------------------------------
 
-#ifdef __APPLE__
-    fs::path p = Stacktrace::getExePath();
-    p /= "../Resources";
+    fs::path p = Util::getDataPath();
     p /= relativePathAndFile;
 
     if (fs::exists(p)) {
@@ -443,33 +436,15 @@ void initResourcePath(GladeSearchpath* gladePath, const gchar* relativePathAndFi
         return;
     }
 
-    string msg = FS(_F("Missing the needed UI file:\n{1}\n .app corrupted?\nPath: {2}") % relativePathAndFile %
-                    p.u8string());
-
-    if (!failIfNotFound) {
-        msg += _("\nWill now attempt to run without this file.");
-    }
-    XojMsgBox::showErrorToUser(nullptr, msg);
-#else
-    // Check at the target installation directory
-    fs::path absolute = PACKAGE_DATA_DIR;
-    absolute /= PROJECT_PACKAGE;
-    absolute /= relativePathAndFile;
-
-    if (fs::exists(absolute)) {
-        gladePath->addSearchDirectory(absolute.parent_path());
-        return;
-    }
-
-    string msg = FS(_F("<span foreground='red' size='x-large'>Missing the needed UI file:\n<b>{1}</b></span>\nCould "
-                       "not find them at any location.\n  Not relative\n  Not in the Working Path\n  Not in {2}") %
-                    relativePathAndFile % PACKAGE_DATA_DIR);
+    std::string msg =
+            FS(_F("<span foreground='red' size='x-large'>Missing the needed UI file:\n<b>{1}</b></span>\nCould "
+                  "not find them at any location.\n  Not relative\n  Not in the Working Path\n  Not in {2}") %
+               relativePathAndFile % Util::getDataPath().string());
 
     if (!failIfNotFound) {
         msg += _("\n\nWill now attempt to run without this file.");
     }
     XojMsgBox::showErrorToUser(nullptr, msg);
-#endif
 
     if (failIfNotFound) {
         exit(12);
@@ -539,8 +514,8 @@ void on_startup(GApplication* application, XMPtr app_data) {
     bool opened = false;
     if (app_data->optFilename) {
         if (g_strv_length(app_data->optFilename) != 1) {
-            string msg = _("Sorry, Xournal++ can only open one file at once.\n"
-                           "Others are ignored.");
+            std::string msg = _("Sorry, Xournal++ can only open one file at once.\n"
+                                "Others are ignored.");
             XojMsgBox::showErrorToUser(static_cast<GtkWindow*>(*app_data->win), msg);
         }
 
@@ -554,15 +529,18 @@ void on_startup(GApplication* application, XMPtr app_data) {
                 opened = app_data->control->newFile("", p);
             }
         } catch (fs::filesystem_error const& e) {
-            string msg = FS(_F("Sorry, Xournal++ cannot open remote files at the moment.\n"
-                               "You have to copy the file to a local directory.") %
-                            p.u8string() % e.what());
+            std::string msg = FS(_F("Sorry, Xournal++ cannot open remote files at the moment.\n"
+                                    "You have to copy the file to a local directory.") %
+                                 p.u8string() % e.what());
             XojMsgBox::showErrorToUser(static_cast<GtkWindow*>(*app_data->win), msg);
             opened = app_data->control->newFile("", p);
         }
     } else if (app_data->control->getSettings()->isAutoloadMostRecent()) {
-        if (auto p = Util::fromUri(gtk_recent_info_get_uri(app_data->control->getRecentManager()->getMostRecent()))) {
-            opened = app_data->control->openFile(*p);
+        auto most_recent = app_data->control->getRecentManager()->getMostRecent();
+        if (most_recent != nullptr) {
+            if (auto p = Util::fromUri(gtk_recent_info_get_uri(most_recent))) {
+                opened = app_data->control->openFile(*p);
+            }
         }
     }
 
