@@ -9,6 +9,7 @@
 #include "gui/PageView.h"
 #include "gui/XournalView.h"
 #include "gui/XournalppCursor.h"
+#include "gui/widgets/XournalWidget.h"
 #include "model/Document.h"
 #include "model/Element.h"
 #include "model/Layer.h"
@@ -28,12 +29,18 @@
 #include "Selection.h"
 #include "i18n.h"
 
+using std::vector;
 
-constexpr size_t MINPIXSIZE = 5;  // smallest can scale down to, in pixels.
+/// Smallest can scale down to, in pixels.
+constexpr size_t MINPIXSIZE = 5;
 
-constexpr int DELETE_PADDING = 20;  // ui button padding
+/// Padding for ui buttons
+constexpr int DELETE_PADDING = 20;
 constexpr int ROTATE_PADDING = 8;
 
+/// Number of times to trigger edge pan timer per second
+constexpr unsigned int PAN_TIMER_RATE = 30;
+
 EditSelection::EditSelection(UndoRedoHandler* undo, const PageRef& page, XojPageView* view):
         snappingHandler(view->getXournal()->getControl()->getSettings()),
         x(0),
@@ -159,6 +166,11 @@ EditSelection::~EditSelection() {
 
     this->view = nullptr;
     this->undo = nullptr;
+
+    if (this->edgePanHandler) {
+        g_source_destroy(this->edgePanHandler);
+        g_source_unref(this->edgePanHandler);
+    }
 }
 
 /**
@@ -247,7 +259,7 @@ auto EditSelection::getSourceLayer() -> Layer* { return this->sourceLayer; }
  */
 auto EditSelection::getXOnViewAbsolute() -> int {
     double zoom = view->getXournal()->getZoom();
-    return this->view->getX() + this->getXOnView() * zoom;
+    return this->view->getX() + static_cast<int>(this->getXOnView() * zoom);
 }
 
 /**
@@ -255,7 +267,7 @@ auto EditSelection::getXOnViewAbsolute() -> int {
  */
 auto EditSelection::getYOnViewAbsolute() -> int {
     double zoom = view->getXournal()->getZoom();
-    return this->view->getY() + this->getYOnView() * zoom;
+    return this->view->getY() + static_cast<int>(this->getYOnView() * zoom);
 }
 
 /**
@@ -324,6 +336,7 @@ void EditSelection::addElement(Element* e, Layer::ElementIndex order) {
  * Returns all containing elements of this selection
  */
 auto EditSelection::getElements() -> vector<Element*>* { return this->contents->getElements(); }
+auto EditSelection::getElements() const -> const vector<Element*>* { return this->contents->getElements(); }
 
 /**
  * Returns the insert order of this selection
@@ -405,7 +418,13 @@ void EditSelection::mouseUp() {
                                   this->view, this->undo, this->mouseDownType);
 
     this->mouseDownType = CURSOR_SELECTION_NONE;
+
+    const bool wasEdgePanning = this->isEdgePanning();
+    this->setEdgePan(false);
     updateMatrix();
+    if (wasEdgePanning) {
+        this->ensureWithinVisibleArea();
+    }
 }
 
 /**
@@ -466,7 +485,12 @@ void EditSelection::mouseMove(double mouseX, double mouseY, bool alt) {
         p = snappingHandler.snapToGrid(p, alt);
 
         // move
-        moveSelection(p.x - cx, p.y - cy);
+        if (!this->edgePanInhibitNext) {
+            moveSelection(p.x - cx, p.y - cy);
+            this->setEdgePan(true);
+        } else {
+            this->edgePanInhibitNext = false;
+        }
     } else if (this->mouseDownType == CURSOR_SELECTION_ROTATE && supportRotation) {  // catch rotation here
         double rdx = mouseX / zoom - this->snappedBounds.x - this->snappedBounds.width / 2;
         double rdy = mouseY / zoom - this->snappedBounds.y - this->snappedBounds.height / 2;
@@ -560,7 +584,7 @@ void EditSelection::mouseMove(double mouseX, double mouseY, bool alt) {
 
     if (v && v != this->view) {
         XournalView* xournal = this->view->getXournal();
-        int pageNr = xournal->getControl()->getDocument()->indexOf(v->getPage());
+        const auto pageNr = xournal->getControl()->getDocument()->indexOf(v->getPage());
 
         xournal->pageSelected(pageNr);
 
@@ -608,7 +632,7 @@ auto EditSelection::getPageViewUnderCursor() -> XojPageView* {
 
 
     Layout* layout = gtk_xournal_get_layout(this->view->getXournal()->getWidget());
-    XojPageView* v = layout->getPageViewAt(hx, hy);
+    XojPageView* v = layout->getPageViewAt(static_cast<int>(hx), static_cast<int>(hy));
 
     return v;
 }
@@ -689,17 +713,106 @@ void EditSelection::moveSelection(double dx, double dy) {
     this->snappedBounds.x += dx;
     this->snappedBounds.y += dy;
 
-    ensureWithinVisibleArea();
-
     updateMatrix();
 
     this->view->getXournal()->repaintSelection();
 }
 
-/**
- * If the selection is outside the visible area correct the coordinates
- */
-void EditSelection::ensureWithinVisibleArea() {
+void EditSelection::setEdgePan(bool pan) {
+    if (pan && !this->edgePanHandler) {
+        this->edgePanHandler = g_timeout_source_new(1000 / PAN_TIMER_RATE);
+        g_source_set_callback(this->edgePanHandler, reinterpret_cast<GSourceFunc>(EditSelection::handleEdgePan), this,
+                              nullptr);
+        g_source_attach(this->edgePanHandler, nullptr);
+    } else if (!pan && this->edgePanHandler) {
+        g_source_destroy(this->edgePanHandler);
+        g_source_unref(this->edgePanHandler);
+        this->edgePanHandler = nullptr;
+        this->edgePanInhibitNext = false;
+    }
+}
+
+bool EditSelection::isEdgePanning() const { return this->edgePanHandler; }
+
+bool EditSelection::handleEdgePan(EditSelection* self) {
+    if (self->view->getXournal()->getControl()->getZoomControl()->isZoomPresentationMode()) {
+        self->setEdgePan(false);
+        return false;
+    }
+
+
+    Layout* layout = gtk_xournal_get_layout(self->view->getXournal()->getWidget());
+    const Settings* const settings = self->getView()->getXournal()->getControl()->getSettings();
+    const double zoom = self->view->getXournal()->getZoom();
+
+    // Helper function to compute scroll amount for a single dimension, based on visible region and selection bbox
+    const auto computeScrollAmt = [&](double visMin, double visLen, double bboxMin, double bboxLen,
+                                      double layoutSize) -> double {
+        const bool belowMin = bboxMin < visMin;
+        const bool aboveMax = bboxMin + bboxLen > visMin + visLen;
+        const double visMax = visMin + visLen;
+        const double bboxMax = bboxMin + bboxLen;
+
+        // Scroll amount multiplier
+        double mult = 0.0;
+
+        // Calculate bonus scroll amount due to proportion of selection out of view.
+        const double maxMult = settings->getEdgePanMaxMult();
+        int panDir = 0;
+        if (aboveMax) {
+            panDir = 1;
+            mult = maxMult * std::min(bboxLen, bboxMax - visMax) / bboxLen;
+        } else if (belowMin) {
+            panDir = -1;
+            mult = maxMult * std::min(bboxLen, visMin - bboxMin) / bboxLen;
+        }
+
+        // Base amount to translate selection (in document coordinates) per timer tick
+        const double panSpeed = settings->getEdgePanSpeed();
+        const double translateAmt = visLen * panSpeed / (100.0 * PAN_TIMER_RATE);
+
+        // Amount to scroll the visible area by (in layout coordinates), accounting for multiplier
+        double layoutScroll = zoom * panDir * (translateAmt * mult);
+
+        // If scrolling past layout boundaries, clamp scroll amount to boundary
+        if (visMin + layoutScroll < 0) {
+            layoutScroll = -visMin;
+        } else if (visMax + layoutScroll > layoutSize) {
+            layoutScroll = std::max(0.0, layoutSize - visMax);
+        }
+
+        return layoutScroll;
+    };
+
+    // Compute scroll (for layout) and translation (for selection) for x and y
+    const int layoutWidth = layout->getMinimalWidth();
+    const int layoutHeight = layout->getMinimalHeight();
+    const auto visRect = layout->getVisibleRect();
+    const auto bbox = self->getBoundingBoxInView();
+    const auto layoutScrollX = computeScrollAmt(visRect.x, visRect.width, bbox.x, bbox.width, layoutWidth);
+    const auto layoutScrollY = computeScrollAmt(visRect.y, visRect.height, bbox.y, bbox.height, layoutHeight);
+    const auto translateX = layoutScrollX / zoom;
+    const auto translateY = layoutScrollY / zoom;
+
+    // Perform the scrolling
+    bool edgePanned = false;
+    if (self->isMoving() && (layoutScrollX != 0.0 || layoutScrollY != 0.0)) {
+        layout->scrollRelative(layoutScrollX, layoutScrollY);
+        self->moveSelection(translateX, translateY);
+        edgePanned = true;
+
+        // To prevent the selection from jumping and to reduce jitter, block the selection movement triggered by user
+        // input
+        self->edgePanInhibitNext = true;
+    } else {
+        // No panning, so disable the timer.
+        self->setEdgePan(false);
+    }
+
+    return edgePanned;
+}
+
+auto EditSelection::getBoundingBoxInView() const -> Rectangle<double> {
     int viewx = this->view->getX();
     int viewy = this->view->getY();
     double zoom = this->view->getXournal()->getZoom();
@@ -713,11 +826,15 @@ void EditSelection::ensureWithinVisibleArea() {
     double minx = cx - w / 2.0;
     double miny = cy - h / 2.0;
 
+    return {viewx + minx * zoom, viewy + miny * zoom, w * zoom, h * zoom};
+}
+
+void EditSelection::ensureWithinVisibleArea() {
+    const Rectangle<double> viewRect = this->getBoundingBoxInView();
     // need to modify this to take into account the position
     // of the object, plus typecast because XojPageView takes ints
-    this->view->getXournal()->ensureRectIsVisible(static_cast<int>(viewx + minx * zoom),
-                                                  static_cast<int>(viewy + miny * zoom), static_cast<int>(w * zoom),
-                                                  static_cast<int>(h * zoom));
+    this->view->getXournal()->ensureRectIsVisible(static_cast<int>(viewRect.x), static_cast<int>(viewRect.y),
+                                                  static_cast<int>(viewRect.width), static_cast<int>(viewRect.height));
 }
 
 /**
@@ -924,7 +1041,7 @@ void EditSelection::drawDeleteRect(cairo_t* cr, double x, double y, double zoom)
 
 auto EditSelection::getView() -> XojPageView* { return this->view; }
 
-void EditSelection::serialize(ObjectOutputStream& out) {
+void EditSelection::serialize(ObjectOutputStream& out) const {
     out.writeObject("EditSelection");
 
     out.writeDouble(this->x);
@@ -940,7 +1057,7 @@ void EditSelection::serialize(ObjectOutputStream& out) {
     this->contents->serialize(out);
     out.endObject();
 
-    out.writeInt(this->getElements()->size());
+    out.writeInt(static_cast<int>(this->getElements()->size()));
     for (Element* e: *this->getElements()) { e->serialize(out); }
 }
 
