@@ -76,8 +76,8 @@ public:
 
     void updateScrollbarSidebarPosition();
 
-    void setUndoDescription(const string& description);
-    void setRedoDescription(const string& description);
+    void setUndoDescription(const std::string& description);
+    void setRedoDescription(const std::string& description);
 
     SpinPageAdapter* getSpinPageNo();
     ToolbarModel* getToolbarModel();
