@@ -26,7 +26,7 @@ public:
 public:
     virtual bool undo(Control* control);
     virtual bool redo(Control* control);
-    virtual string getText();
+    virtual std::string getText();
 
     void addStroke(Stroke* s, int originalFill, int newFill);
 
