@@ -20,30 +20,27 @@
 #include "control/settings/Settings.h"
 #include "gui/inputdevices/InputEvents.h"
 
-using std::string;
-using std::vector;
-
 class InputDevice {
 public:
     explicit InputDevice(GdkDevice* device);
-    explicit InputDevice(string name, GdkInputSource source);
+    explicit InputDevice(std::string name, GdkInputSource source);
     ~InputDevice() = default;
 
 public:
-    string getType() const;
-    string getName() const;
+    std::string getType() const;
+    std::string getName() const;
     GdkInputSource getSource() const;
     void updateType(GdkInputSource newSource);
 
     bool operator==(const InputDevice& inputDevice) const;
 
 private:
-    string name;
+    std::string name;
     GdkInputSource source;
 };
 
 namespace DeviceListHelper {
 
-vector<InputDevice> getDeviceList(Settings* settings, bool ignoreTouchDevices = false);
+std::vector<InputDevice> getDeviceList(Settings* settings, bool ignoreTouchDevices = false);
 InputDeviceClass getSourceMapping(GdkInputSource src, Settings* settings);
-}
+}  // namespace DeviceListHelper
